@@ -1,7 +1,7 @@
 package App::CryptoCurrencyUtils;
 
 our $DATE = '2018-01-30'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,18 +9,18 @@ use warnings;
 
 our %SPEC;
 
-our %arg_symbol_or_name = (
-    symbol_or_name => {
+our %arg_coin = (
+    coin => {
         schema => 'cryptocurrency::symbol_or_name*',
         req => 1,
         pos => 0,
     },
 );
 
-our %arg_symbols_or_names = (
-    symbols_or_names => {
+our %arg_coins = (
+    coins => {
         'x.name.is_plural' => 1,
-        'x.name.singular' => 'symbol_or_name',
+        'x.name.singular' => 'coin',
         schema => ['array*', of=>'cryptocurrency::symbol_or_name*'],
         req => 1,
         pos => 0,
@@ -28,11 +28,30 @@ our %arg_symbols_or_names = (
     },
 );
 
+our %arg_exchange = (
+    exchange => {
+        schema => 'cryptoexchange::name*',
+        req => 1,
+        pos => 0,
+    },
+);
+
+our %arg_exchanges = (
+    exchanges => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'exchange',
+        schema => ['array*', of=>'cryptoexchange::name*'],
+        req => 1,
+        pos => 0,
+        greedy => 1,
+    },
+);
+
 $SPEC{coin_cmc} = {
     v => 1.1,
     summary => "Go to coin's CMC (coinmarketcap.com) currency page",
     args => {
-        %arg_symbols_or_names,
+        %arg_coins,
     },
 };
 sub coin_cmc {
@@ -42,7 +61,7 @@ sub coin_cmc {
     my $cat = CryptoCurrency::Catalog->new;
 
   CURRENCY:
-    for my $cur0 (@{ $args{symbols_or_names} }) {
+    for my $cur0 (@{ $args{coins} }) {
 
         my $cur;
         {
@@ -72,7 +91,7 @@ there is a difference.
 
 _
     args => {
-        %arg_symbols_or_names,
+        %arg_coins,
     },
 };
 sub coin_mno {
@@ -84,7 +103,7 @@ sub coin_mno {
     my $cat = CryptoCurrency::Catalog->new;
 
   CURRENCY:
-    for my $cur0 (@{ $args{symbols_or_names} }) {
+    for my $cur0 (@{ $args{coins} }) {
 
         my $cur;
         {
@@ -105,6 +124,38 @@ sub coin_mno {
     [200];
 }
 
+$SPEC{exchange_cmc} = {
+    v => 1.1,
+    summary => "Go to exchange's CMC (coinmarketcap.com) exchange page",
+    args => {
+        %arg_exchanges,
+    },
+};
+sub exchange_cmc {
+    require CryptoExchange::Catalog;
+    my %args = @_;
+
+    my $cat = CryptoExchange::Catalog->new;
+
+  CURRENCY:
+    for my $xchg0 (@{ $args{exchanges} }) {
+
+        my $xchg;
+        {
+            eval { $xchg = $cat->by_name($xchg0) };
+            last if $xchg;
+            warn "No such cryptoexchange name '$xchg0'";
+            next CURRENCY;
+        }
+
+        require Browser::Open;
+        my $url = "https://coinmarketcap.com/exchanges/$xchg->{safename}/";
+        my $err = Browser::Open::open_browser($url);
+        return [500, "Can't open browser for '$url'"] if $err;
+    }
+    [200];
+}
+
 $SPEC{list_coins} = {
     v => 1.1,
     summary => "List cryptocurrency coins",
@@ -123,6 +174,25 @@ sub list_coins {
     [200, "OK", [CryptoCurrency::Catalog->new->all_data]];
 }
 
+
+$SPEC{list_exchanges} = {
+    v => 1.1,
+    summary => "List cryptocurrency exchanges",
+    description => <<'_',
+
+This utility lists cryptocurrency exchanges from <pm:CryptoExchange::Catalog>,
+which in turn gets its list from <https://coinmarketcap.com/>.
+
+_
+    args => {
+    },
+};
+sub list_exchanges {
+    require CryptoExchange::Catalog;
+
+    [200, "OK", [CryptoExchange::Catalog->new->all_data]];
+}
+
 1;
 # ABSTRACT: CLI utilities related to cryptocurrencies
 
@@ -138,7 +208,7 @@ App::CryptoCurrencyUtils - CLI utilities related to cryptocurrencies
 
 =head1 VERSION
 
-This document describes version 0.006 of App::CryptoCurrencyUtils (from Perl distribution App-CryptoCurrencyUtils), released on 2018-01-30.
+This document describes version 0.007 of App::CryptoCurrencyUtils (from Perl distribution App-CryptoCurrencyUtils), released on 2018-01-30.
 
 =head1 DESCRIPTION
 
@@ -150,10 +220,16 @@ This distribution contains the following CLI utilities:
 
 =item * L<coin-mno>
 
+=item * L<exchange-cmc>
+
 =item * L<grep-coin>
 
+=item * L<grep-exchange>
+
 =item * L<list-coins>
 
+=item * L<list-exchanges>
+
 =back
 
 =head1 FUNCTIONS
@@ -173,7 +249,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<symbols_or_names>* => I<array[cryptocurrency::symbol_or_name]>
+=item * B<coins>* => I<array[cryptocurrency::symbol_or_name]>
 
 =back
 
@@ -206,7 +282,37 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<symbols_or_names>* => I<array[cryptocurrency::symbol_or_name]>
+=item * B<coins>* => I<array[cryptocurrency::symbol_or_name]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 exchange_cmc
+
+Usage:
+
+ exchange_cmc(%args) -> [status, msg, result, meta]
+
+Go to exchange's CMC (coinmarketcap.com) exchange page.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<exchanges>* => I<array[cryptoexchange::name]>
 
 =back
 
@@ -248,6 +354,33 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 list_exchanges
+
+Usage:
+
+ list_exchanges() -> [status, msg, result, meta]
+
+List cryptocurrency exchanges.
+
+This utility lists cryptocurrency exchanges from L<CryptoExchange::Catalog>,
+which in turn gets its list from L<https://coinmarketcap.com/>.
+
+This function is not exported.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-CryptoCurrencyUtils>.
